#! /usr/bin/perl -w

# wsdffindmaker.pl
#
# Author: Robert Hahn <rh-wsdf@tenletters.com>
#
# Copyright: (c) 2003 Permission granted to use this code provided that 
#            proper credit is given to the original author.
# 
# Date: December 8, 2003
#
# The purpose of this script is to generate a search page.  The thinking behind
# writing this is that the rate at which I'm adding posts to a site is low
# enough that the costs of dynamically generating this page is too high to be
# worth the bother.
#
# Requirements:
#
# XML::XPath, which is based on libxml2, I believe, 
# taken from the gnome project. I selected this library because I found the
# engine to be the fastest I've ever used, and seems to be one of the most
# mature.  If you don't have this bit of infrastructure handy, you may have
# some work cut out for you.  My experience (on Mac OS X) has been tedious
# but problem free: I merely had to fetch and install a fairly lengthly list
# of prereqs, but all makes, make-tests, and make installs went fairly 
# smoothly.
#
# This script is provided in 'as is' condition. No warranties, no guarantees,
# etc.  I'm providing this to you so that you can see how to create a search
# page based on the contents of your WSDF file.  It's rough around the edges,
# but the script did what I needed it to do, and will probably work for you, 
# too.
#
# Invocation:
#
# ./wsdffindmaker.pl wsdf.html > searchpage.html
#
# What this script does is read in a default search page template (findit.html),
# reads in the contents of the wsdf.html file you made up, then pokes through
# the wsdf file looking for section titles and mimetypes.  Once it's found those
# things, it assembles the data into some option tags and inserts the results
# into the findit.html template, and finally prints the results out to STDOUT.
# 

use XML::XPath;
use XML::XPath::XMLParser;

$file = $ARGV[0];

# read in the template
open HTML, "./findit.html";
	while ( <HTML> ) {
			$data .= $_;
	}
close HTML;

my $parsefile = XML::XPath->new(filename => $file);

my $sections = "";

# find all the titles in the wsdf file
my $titles = $parsefile->find('/html/body//div/@title');

foreach my $node ($titles->get_nodelist) {
		$nodetext = $node->getData;
		# convert the findings into option tags.
		$sections .= "<option value=\"$nodetext\">$nodetext</option>\n";
}

# find all the mime types in the wsdf file.
my $obj_types = $parsefile->find('/html/body//div/object/@type');

foreach my $node ($obj_types->get_nodelist) {
		$nodetext = $node->getData;

		# This is a trick I use to ensure that I'm only getting one copy
		# of each mimeType.
		$mimeType{$nodetext} = 1;
}

my $assets = "";

foreach $type (sort keys(%mimeType)) {
		$type =~ /.*\/(.*)/;
		# convert the sorted list of mimetypes to option tags
		$assets .= "<option value=\"$type\">$2 files</option>\n";
}

# paste the option tags into the template
$data =~ s/\$sections/$sections/;
$data =~ s/\$assets/$assets/;

# ...and send it on out
print $data;


1;

