#! /usr/bin/perl -w

# wsdffind.cgi
#
# Author: Robert Hahn <rh-wsdf@tenletters.com>
#
# Copyright: (c) 2003 Permission granted to use this code provided that
# 			 proper credit is given to the original author.
# 			 
# Date: December 8, 2003
# 
# This is a first rough cut at a CGI script designed to search a WSDF and
# return hopefully relevant results.  Proof of concept only. This is provided
# 'as is', has no warranties or guarantees, and is merely provided to give you as sense of how to work with WSDFs.
#
# Requirements:
#
# You'll need XML::XPath (and all the prereqs that go with that) installed.  
# XML::XPath is built on the LibXML2 engine provided by the good folks in 
# the gnome project. As a Mac OS X 10.2 user, I encountered no problems
# installing all the prereqs and getting it running.  
#
# Invocation:
#
# It's a cgi.
#
# This is probably about the worst search engine in the world, but the point I
# want to get across is that you can search a WSDF file for possibly 'better'
# information than brute-forcing your way through all the HTML files.  The value
# is probably best shown when you want to search for non-HTML content, like
# image files or JavaScript files, which are typically opaque to traditional 
# text searches.
#
# How the program works here was better documented in-line to the code, so
# read on for that high-level overview.

use XML::XPath;
use XML::XPath::XMLParser;
use CGI;

my $query = new CGI;

# USER CONFIGURABLE VARIABLE
# set the value of $file to point to your wsdf.html file.
my $file = "./wsdf.html";

my $section = $query->param('section');
my $assets = $query->param('assets'); 
my $searchTerms = $query->param('searchTerms');

# Construct XPath
my $xp = "/html/body/";

if ($section eq "*" or $section eq "") {
		# If the Section drop down didn't have a specific value, then don't add
		# anything to the XPath.
		$xp .= "/";
} else {
		# else, add in a search constraint that matches only those sections
		# that contain the selected title.
		$xp .= '/div[@title=\''.$section.'\']/';
}

if ($assets eq "*" or $assets eq "") {
		# if no mimetype is specified, then select any object
		$xp .= "object";
} else {
		# otherwise, select only those objects matching a particular mimetype
		$xp .= 'object[@type="'.$assets.'"]';
}

# print some debug info to the web error log -- all prints to STDERR will be 
# doing that.
print STDERR "\n\n";
print STDERR $xp."\n\n";

my $parsefile = XML::XPath->new(filename => $file);

print STDERR "parsed...\n";

# Get search results
my $results = $parsefile->find($xp);

print STDERR "results obtained...\n";

# using CGI's built in HTML generator to print the header and some of the
# HTML output

print $query->header,
		$query->start_html('Search Results'),
		$query->h1('Search Results');

# The actual search terms, if submitted with the form, are prepared
# for processing here.
@searchTerms = split (/ /, $searchTerms);

print "<ul>\n";

foreach my $node ($results->get_nodelist) {
		# get the stuff between the open and close object tags
		$nodetext = $node->string_value();

		# get the URI of the object
		$link = $node->getAttribute('data');

		$printit = 0;

		# I don't know if this is the best way to do it, but this is my
		# attempt at doing an AND match.
		foreach $term (@searchTerms) {
			if(index(lc($nodetext), lc($term)) > -1) {
					$printit ++;
			}
		}

		# See, here I'm checking to see if the number of hits on my search
		# terms equals the number of search terms. If it is, then I can print
		# the result set.   Feel free to improve, I'm only trying to
		# demonstrate how this could work.
		if (scalar(@searchTerms) == $printit) {
			print '<li>'.$nodetext.' -<i><a href="'.$link.'">Link...</a></i.</li>\n';
		}
}

print "</ul>\n";
print $query->end_html;

1;

